| Title: | Hematimetric Indices Calculator |
|---|---|
| Description: | Tools to calculate Mean Corpuscular Volume, Mean Corpuscular Hemoglobin, and Mean Corpuscular Hemoglobin Concentration, which are essential for assessing red blood cell health and diagnosing blood disorders. |
| Authors: | Andre Luis Fernandes dos Santos [aut, cre] (ORCID: <https://orcid.org/0000-0001-7053-4989>) |
| Maintainer: | Andre Luis Fernandes dos Santos <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.1.3 |
| Built: | 2026-05-19 09:07:13 UTC |
| Source: | https://github.com/cran/hemat |
Calculates the MCH based on hemoglobin concentration and red blood cell count. MCH measures the average amount of hemoglobin per red blood cell.
calc_mch(hb, rb)calc_mch(hb, rb)
hb |
Numeric value representing the hemoglobin concentration in g/dL. |
rb |
Numeric value representing the red blood cell count (millions/ µL). |
Numeric value representing the MCH in picograms (pg).
calc_mch(15, 5)calc_mch(15, 5)
Calculates the MCHC based on hemoglobin concentration and hematocrit. MCHC measures the average concentration of hemoglobin in red blood cells.
calc_mchc(hb, ht)calc_mchc(hb, ht)
hb |
Numeric value representing the hemoglobin concentration in g/dL. |
ht |
Numeric value representing the hematocrit in percentage. |
Numeric value representing the MCHC in grams per deciliter (g/dL).
calc_mchc(15, 40)calc_mchc(15, 40)
MCV measures the average volume of red blood cells in a blood sample.
calc_mcv(ht, rb)calc_mcv(ht, rb)
ht |
Numeric value representing the hematocrit in percentage. |
rb |
Numeric value representing the red blood cell count (millions/ µL). |
Numeric value representing the MCV in femtoliters (fL).
calc_mcv(40, 5)calc_mcv(40, 5)